#
# jt-data_fishing.R, 25 Sep 22
#
# Data from:
# https://www.bls.gov/jlt/data.htm
# For data description see: https://download.bls.gov/pub/time.series/jt/

library("colorspace")
library("plyr")


par(bty="l")
par(las=1)
par(pch="+")
pal_col=rainbow(3)


sum_data=function(delem)
{
HI=subset(info_c, dataelem ==delem)
t=ddply(HI, .(date), function(df) sum(df$value))
return(subset(t, !is.na(date))) # The latest date is sometime NA
}


plot_acf=function(vec, v_str)
{
acf(diff(vec), main="", xlab="Lag (months)")
text(10, 0.9, v_str, cex=1.2)
return(NULL)
}


plot_ccf=function(vec1, vec2, v_str)
{
ccf(vec1, vec2, main="", xlab="Lag (months)")
text(0, -0.1, v_str, cex=1.2)
return(NULL)
}


jt=read.csv("jt.data.1.AllItems.xz", as.is=TRUE, sep="\t")

# The series_id (JTS000000000000000JOR) can be broken out into:
# 
# Code				Value
# 
# survey abbreviation	=	JT
# seasonal (code) 	=	S
# industry_code		=	000000
# state_code		=	00
# area_code		=	00000
# sizeclass_code	=	00
# dataelement_code	=	JO
# ratelevel_code	=	R
# 

# Industry code
# 000000 Total nonfarm
# 100000 Total privat
# 510000 Information

information_code="510000"

# sizeclass_code
# 00	All size classes
# 01	1 to 9 employees
# 02	10 to 49 employees
# 03	50 to 249 employees
# 04	250 to 999 employees
# 05	1,000 to 4,999 employees
# 06	5,000 or more employees

# seasonal_code	seasonal_text
# S	Seasonally Adjusted
# U	Not Seasonally Adjusted
tr(info_c)
# ratelevel_code	ratelevel_text
# L	Level - In Thousands
# R	Rate

# dataelement_code	dataelement_text
# HI	Hires
# JO	Job openings
# LD	Layoffs and discharges
# OS	Other separations
# QU	Quits
# TS	Total separations
# UN	Unemployment rate
# UO	Unemployed persons per job opening ratio

# M01 is January, etc
jt$date=as.Date(paste0(jt$year, "-", substr(jt$period, 2, 3), "-01"), format="%Y-%m-%d")

jt$sabbrev=substr(jt$series_id, 1, 2)
jt$seasonal=substr(jt$series_id, 3, 3)
jt$ind_code=substr(jt$series_id, 4, 9)
jt$state_code=substr(jt$series_id, 10, 11)
jt$area_code=substr(jt$series_id, 12, 16)
jt$sizeclass=substr(jt$series_id, 17, 18)
jt$dataelem=substr(jt$series_id, 19, 20)
jt$ratelevel=substr(jt$series_id, 21, 21)

jt_u=subset(jt, seasonal == "U") # The not seasonally corrected data
jt_ul=subset(jt_u, ratelevel == "L") # The actual numbers, not percentage

info_c=subset(jt_ul, ind_code == information_code)

HI=sum_data("HI")
JO=sum_data("JO")
LD=sum_data("LD")
QU=sum_data("QU")

pal_col=rainbow(4)
par(mfcol=c(1, 1))

plot(HI$date, HI$V1, col=pal_col[3], type="l",
	xaxs="i", yaxs="i",
	ylim=c(0, 300),
	xlab="Date (monthly)", ylab="Quantity (thousands)")
lines(JO$date, JO$V1, col=pal_col[2])
lines(QU$date, QU$V1, col=pal_col[4])
lines(LD$date, LD$V1, col=pal_col[1])

legend("top", legend=c("Job openings", "Hires", "Quits", "Layoffs"),
                        fill=pal_col[c(2, 3, 4, 1)], border="white", bty="n")

par(mfcol=c(2, 2))
par(mar=c(4, 4, 1, 1))
plot_acf(HI$V1, "Hires")
plot_acf(JO$V1, "Job Openings")
plot_acf(QU$V1, "Quits")
plot_acf(LD$V1, "Layoffs")

plot_ccf(HI$V1, LD$V1, "Hires & Layoffs")
plot_ccf(QU$V1, LD$V1, "Quits & Layoffs")
# ccf(JO$V1, LD$V1) # Very little cross correlation
# plot_ccf(JO$V1, QU$V1, "Job Openings & Quits")
plot_ccf(JO$V1, HI$V1, "Job Openings & Hires")
#plot_ccf(JO$V1, LD$V1, "Job Openings & Layoffs")
plot_ccf(HI$V1, QU$V1, "Hires & Quits")

cor(HI$V1, QU$V1)
# [1] 0.6899079


